import arcpy
import os
arcpy.env.overwriteOutput = True
#nastavení do paměti, aby se neukládaly vrstvy vytvořené v mezikrocích
arcpy.env.workspace = "in_memory"

# Nastavte cestu do složky, kde jsou všechny rozzipované složky stažených katastrů
slozka_workspace = arcpy.GetParameterAsText(0)

# Kam se uloží spojené parcely a jak se budou jmenovat
propojene_parcely_KU = arcpy.GetParameterAsText(1)
# Kam se uloží spojené k.ú. a jak se budou jmenovat
cele_KU = arcpy.GetParameterAsText(2)


try:
    #######POLYGONOVÉ VRSTVY PARCEL
    ######

    # Seznam nalezených polygonových vrstev
    seznam_polygonu = []

    # Projde všechny složky ve workspace a hledá shapefile "PARCELY_KN_P.shp"
    for root, dirs, files in os.walk(slozka_workspace):
        for file in files:
            if file == "PARCELY_KN_P.shp":
                full_path = os.path.join(root, file)
                #doplníme chybějící informaci o souřadnicovém systému
                arcpy.DefineProjection_management(full_path, arcpy.SpatialReference(5514))
                #zápis do seznamu
                seznam_polygonu.append(full_path)
                
    # Spojení všech vybraných shp do jedné vrstvy
    spojene_polygony = arcpy.Merge_management(seznam_polygonu, "parcely_polygony")

    #####POPISKY PARCEL
    #####

    # Seznam nalezených bodových vrstev
    seznam_bodu = []

    # Projde všechny složky ve workspace a hledá shapefile "PARCELY_KN_T.shp"
    for root, dirs, files in os.walk(slozka_workspace):
        for file in files:
            if file == "PARCELY_KN_T.shp":
                full_path = os.path.join(root, file)
                #doplníme chybějící informaci o souřadnicovém systému
                arcpy.DefineProjection_management(full_path, arcpy.SpatialReference(5514))
                #zápis do seznamu
                seznam_bodu.append(full_path)
                
    # Spojení všech vybraných shp do jedné vrstvy
    spojene_body = arcpy.Merge_management(seznam_bodu, "parcely_body")


    #######PROPOJENÍ
    #####
    
    arcpy.SpatialJoin_analysis(spojene_polygony, spojene_body, propojene_parcely_KU, join_operation="JOIN_ONE_TO_ONE", join_type="KEEP_ALL", match_option="CONTAINS")
    #"JOIN_ONE_TO_ONE", což znamená, že každý prvek výstupní vrstvy bude mít odpovídající prvek z obou vstupních vrstev (propojené atributy)
    #"KEEP_ALL", což znamená, že všechny prvky ze vstupních vrstev budou zachovány výstupní vrstvě
    #"CONTAINS", spojuje na základě toho, že body leží v daném polygonu (polygon obsahuje bod)
    ################################################################################
except:
    arcpy.AddMessage("Nezadáno umístění")

try:
    #######POLYGONOVÉ VRSTVY KATASTRÁLNÍHO ÚZEMÍ
    ######

    # Seznam nalezených polygonových vrstev
    seznam_polygonu_KU = []


    # Projde všechny složky ve workspace a hledá shapefile "KATASTRALNI_UZEMI_P.shp"
    for root, dirs, files in os.walk(slozka_workspace):
        for file in files:
            if file == "KATASTRALNI_UZEMI_P.shp":
                full_path = os.path.join(root, file)
                #doplníme chybějící informaci o souřadnicovém systému
                arcpy.DefineProjection_management(full_path, arcpy.SpatialReference(5514))
                #zápis do seznamu
                seznam_polygonu_KU.append(full_path)
                
    # Spojení všech vybraných shp do jedné vrstvy
    spojene_polygony_KU = arcpy.Merge_management(seznam_polygonu_KU, "polygony_KU")

    #####POPISKY k.ú.
    #####

    # Seznam nalezených bodových vrstev
    seznam_bodu_KU = []


    # Projde všechny složky ve workspace a hledá shapefile "KATASTRALNI_UZEMI_DEF.shp"
    for root, dirs, files in os.walk(slozka_workspace):
        for file in files:
            if file == "KATASTRALNI_UZEMI_DEF.shp":
                full_path = os.path.join(root, file)
                #doplníme chybějící informaci o souřadnicovém systému
                arcpy.DefineProjection_management(full_path, arcpy.SpatialReference(5514))
                #zápis do seznamu
                seznam_bodu_KU.append(full_path)
                
    # Spojení všech vybraných shp do jedné vrstvy
    spojene_body_KU = arcpy.Merge_management(seznam_bodu_KU, "body_KU")


    #######PROPOJENÍ
    ######

    
    arcpy.SpatialJoin_analysis(spojene_polygony_KU, spojene_body_KU, cele_KU, join_operation="JOIN_ONE_TO_ONE", join_type="KEEP_ALL", match_option="CONTAINS")
except:
    arcpy.AddMessage("Nezadáno umístění k.ú.")
