import arcpy
arcpy.env.workspace = "in_memory"
arcpy.env.overwriteOutput = True

# Načti vstupy jako seznam tabulek
tabulky = arcpy.GetParameterAsText(0).split(";")  # Rozdělení názvů tabulek podle středníku

ulozeni_linie = arcpy.GetParameterAsText(1)
polygonova_vrstva = arcpy.GetParameterAsText(2)
obalka = arcpy.GetParameterAsText(3)

#Pro vrstvy s vícero obrazci
try:
    # Vytvoř prázdný seznam pro ukládání vrstev
    vrstvy = []
    # Pro každou vstupní tabulku
    for idx, tabulka in enumerate(tabulky):
        # Načíst data z tabulky do bodové vrstvy 
        body = arcpy.management.XYTableToPoint(tabulka, f"vystup_body_{idx}", "X", "Y", "", arcpy.SpatialReference("S-JTSK_Krovak_East_North"))
        #je přidáno u výstupu "f"(f-string = formátovaný řetězec)
        
        # Points to Line s možností uzavření - vytvoří dočasnou vrstvu v paměti
        linie = arcpy.management.PointsToLine(body, f"vystup_linie_{idx}", "", "", "CLOSE")

        # Přidání vrstvy do seznamu
        vrstvy.append(linie)

        # Vytvoření liniové vrstvy
    #pro fyzickou vrstvu
    try:
        # Sloučení všech vytvořených liniových vrstev do jedné vrstvy
        hranice = arcpy.management.Merge(vrstvy, ulozeni_linie)
        polygon = arcpy.management.FeatureToPolygon(hranice, polygonova_vrstva)
        #####pro výpočet rozlohy 
        arcpy.AddField_management(polygon, "rozloha", "DOUBLE")
        arcpy.CalculateField_management(polygon, "rozloha", '!shape.area@hectares!','PYTHON3')
    #pouze pro paměť
    except:
        hranice = arcpy.management.Merge(vrstvy, "hranice")
        polygon = arcpy.management.FeatureToPolygon(hranice, "polygonova_vrstva")

    ##když je tabulka jen 1, selže indexovani... takže půjde na except

#pro území s 1 obrazcem
except:    
    # Načtení dat z tabulky do bodové vrstvy
    body = arcpy.management.XYTableToPoint(tabulky[0],"output_point_fc", "X", "Y", "", arcpy.SpatialReference("S-JTSK_Krovak_East_North"))

    # 2. Points to Line s možností uzavření - vytvoří dočasnou vrstvu v paměti
    linie = arcpy.management.PointsToLine(body, "output_line_fc", "", "", "CLOSE")

    #převedení na liniovou vrstvu
    try:
        #Points to Line s možností uzavření - vytvoří se vrstva
        linie = arcpy.management.PointsToLine(body, ulozeni_linie, "", "", "CLOSE")
        polygon = arcpy.management.FeatureToPolygon(linie,polygonova_vrstva)
        #####pro výpočet rozlohy 
        arcpy.AddField_management(polygon, "rozloha", "DOUBLE")
        arcpy.CalculateField_management(polygon, "rozloha", '!shape.area@hectares!','PYTHON3')
        
    except:
        #Points to Line s možností uzavření - vytvoří dočasnou vrstvu v paměti
        linie = arcpy.management.PointsToLine(body, "output_line_fc", "", "", "CLOSE")
        polygon = arcpy.management.FeatureToPolygon(linie,"polygonova_vrstva")


######Obálka
cela_obalka = arcpy.management.MinimumBoundingGeometry(polygon,obalka, "ENVELOPE", "ALL")
#výpočet šířky a výšky obálky
arcpy.AddField_management(cela_obalka, "sirka", "DOUBLE")
arcpy.AddField_management(cela_obalka, "vyska", "DOUBLE")
arcpy.CalculateField_management(cela_obalka, "sirka","!shape.extent.width!")
arcpy.CalculateField_management(cela_obalka, "vyska","!shape.extent.height!")

##Orientace A4:
#vytvoření proměnné pro porovnání (pomocí řetězce """, aby se zachovalo formátování)
porovnani = """
def check(sirka, vyska):
    if (sirka > vyska):
        return "Na šířku"
    else:
        return "Na výšku" """
arcpy.AddField_management(cela_obalka, "orientace_A4", "TEXT")
arcpy.CalculateField_management(cela_obalka, "orientace_A4", "check(!sirka!,!vyska!)",
                                "PYTHON3", porovnani)

##výpočet měřítka na základě rozměrů obálky a určení minimální velikosti na A4 rovno 18 cm
meritko = """
def check(orientace_A4, sirka, vyska):
    if (orientace_A4 == "Na šířku"):
        return sirka*100/18
    else:
        return vyska*100/18 """

arcpy.AddField_management(cela_obalka, "vypocet_meritka", "DOUBLE")
arcpy.CalculateField_management(cela_obalka, "vypocet_meritka", "check(!orientace_A4!,!sirka!,!vyska!)","PYTHON3", meritko)
